@@ -1,7 +1,7 @@
 import datetime
 import requests
 
-def prices():
+class Prices:
     exchange_prices = []
     currency_code = ['USD','NOK','EUR']
     for currency in currency_code:
